pyareas
=======
A simple Python library for finding the areas of 2D shapes
----------------------------------------------------------
Shapes Included:
----------------
- Square
- Triangle
- Rectangle
- Circle
- Parellelogram
- Ellipse
- Rhombus
- Trapezoid
- Polygon(regular)
- Kite
- Pentagram

Install command:
----------------
```
pip install pyareas
```

Example:
--------
```
from pyareas import *

print(Square(10))
```
Gives the output:
```
100
```

To do:
------
- Add more shapes
- Create a new library for volume of 3D shapes
	- pyvolumes?
	- pyareas3d?
